# airnet

[![PyPI - Version](https://img.shields.io/pypi/v/airnet.svg)](https://pypi.org/project/airnet)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/airnet.svg)](https://pypi.org/project/airnet)
![Python package](https://github.com/building-physics/airnet-python/actions/workflows/python-package.yml/badge.svg)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install airnet
```

## License

`airnet` is distributed under the terms of the [BSD-3-Clause](https://spdx.org/licenses/BSD-3-Clause.html) license.
